==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UDPRouteFluentImpl<A extends UDPRouteFluent<A>> extends BaseFluent<A> implements UDPRouteFluent<A>{
  public UDPRouteFluentImpl() {
  }
  public UDPRouteFluentImpl(UDPRoute instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private UDPRouteSpecBuilder spec;
  private UDPRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public UDPRouteFluent.MetadataNested<A> withNewMetadata() {
    return new UDPRouteFluentImpl.MetadataNestedImpl();
  }
  public UDPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new UDPRouteFluentImpl.MetadataNestedImpl(item);
  }
  public UDPRouteFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public UDPRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(UDPRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new UDPRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public UDPRouteFluent.SpecNested<A> withNewSpec() {
    return new UDPRouteFluentImpl.SpecNestedImpl();
  }
  public UDPRouteFluent.SpecNested<A> withNewSpecLike(UDPRouteSpec item) {
    return new UDPRouteFluentImpl.SpecNestedImpl(item);
  }
  public UDPRouteFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public UDPRouteFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new UDPRouteSpecBuilder().build());
  }
  public UDPRouteFluent.SpecNested<A> editOrNewSpecLike(UDPRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public UDPRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(UDPRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new UDPRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public UDPRouteFluent.StatusNested<A> withNewStatus() {
    return new UDPRouteFluentImpl.StatusNestedImpl();
  }
  public UDPRouteFluent.StatusNested<A> withNewStatusLike(UDPRouteStatus item) {
    return new UDPRouteFluentImpl.StatusNestedImpl(item);
  }
  public UDPRouteFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public UDPRouteFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new UDPRouteStatusBuilder().build());
  }
  public UDPRouteFluent.StatusNested<A> editOrNewStatusLike(UDPRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UDPRouteFluentImpl that = (UDPRouteFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<UDPRouteFluent.MetadataNested<N>> implements UDPRouteFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends UDPRouteSpecFluentImpl<UDPRouteFluent.SpecNested<N>> implements UDPRouteFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(UDPRouteSpec item) {
      this.builder = new UDPRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new UDPRouteSpecBuilder(this);
    }
    UDPRouteSpecBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends UDPRouteStatusFluentImpl<UDPRouteFluent.StatusNested<N>> implements UDPRouteFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(UDPRouteStatus item) {
      this.builder = new UDPRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new UDPRouteStatusBuilder(this);
    }
    UDPRouteStatusBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UDPRouteFluentImpl<A extends UDPRouteFluent<A>> extends BaseFluent<A> implements UDPRouteFluent<A>{
  public UDPRouteFluentImpl() {
  }
  public UDPRouteFluentImpl(UDPRoute instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private UDPRouteSpecBuilder spec;
  private UDPRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public UDPRouteFluentImpl.MetadataNested<A> withNewMetadata() {
    return new UDPRouteFluentImpl.MetadataNestedImpl();
  }
  public UDPRouteFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new UDPRouteFluentImpl.MetadataNestedImpl(item);
  }
  public UDPRouteFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public UDPRouteFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public UDPRouteFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public UDPRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(UDPRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new UDPRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public UDPRouteFluentImpl.SpecNested<A> withNewSpec() {
    return new UDPRouteFluentImpl.SpecNestedImpl();
  }
  public UDPRouteFluentImpl.SpecNested<A> withNewSpecLike(UDPRouteSpec item) {
    return new UDPRouteFluentImpl.SpecNestedImpl(item);
  }
  public UDPRouteFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public UDPRouteFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new UDPRouteSpecBuilder().build());
  }
  public UDPRouteFluentImpl.SpecNested<A> editOrNewSpecLike(UDPRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public UDPRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(UDPRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new UDPRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public UDPRouteFluentImpl.StatusNested<A> withNewStatus() {
    return new UDPRouteFluentImpl.StatusNestedImpl();
  }
  public UDPRouteFluentImpl.StatusNested<A> withNewStatusLike(UDPRouteStatus item) {
    return new UDPRouteFluentImpl.StatusNestedImpl(item);
  }
  public UDPRouteFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public UDPRouteFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new UDPRouteStatusBuilder().build());
  }
  public UDPRouteFluentImpl.StatusNested<A> editOrNewStatusLike(UDPRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UDPRouteFluentImpl that = (UDPRouteFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<UDPRouteFluentImpl.MetadataNested<N>> implements UDPRouteFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends UDPRouteSpecFluentImpl<UDPRouteFluentImpl.SpecNested<N>> implements UDPRouteFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(UDPRouteSpec item) {
      this.builder = new UDPRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new UDPRouteSpecBuilder(this);
    }
    UDPRouteSpecBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends UDPRouteStatusFluentImpl<UDPRouteFluentImpl.StatusNested<N>> implements UDPRouteFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(UDPRouteStatus item) {
      this.builder = new UDPRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new UDPRouteStatusBuilder(this);
    }
    UDPRouteStatusBuilder builder;
    public N and() {
      return (N) UDPRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
